@@ -25,9 +25,13 @@ package processing.app;
 
 import java.awt.*;
 import java.awt.event.*;
+
 import javax.swing.*;
 
+import processing.app.helpers.OSUtils;
+
 import java.awt.datatransfer.*;
+
 import static processing.app.I18n._;
 
 
@@ -76,6 +80,7 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
   //Thread promptThread;
   int response;
 
+  boolean initialized = false;
 
   public EditorStatus(Editor editor) {
     this.editor = editor;
@@ -112,7 +117,8 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
   public void notice(String message) {
     mode = NOTICE;
     this.message = message;
-    copyErrorButton.setVisible(false);
+    if (copyErrorButton != null)
+      copyErrorButton.setVisible(false);
     //update();
     repaint();
   }
@@ -125,7 +131,8 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
   public void error(String message) {
     mode = ERR;
     this.message = message;
-//    copyErrorButton.setVisible(true);
+    if (copyErrorButton != null)
+      copyErrorButton.setVisible(true);
     repaint();
   }
 
@@ -196,7 +203,7 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
     progressBar.setIndeterminate(true);
     progressBar.setValue(50);
     progressBar.setVisible(true);
-//    copyErrorButton.setVisible(false);
+    copyErrorButton.setVisible(false);
     setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
     repaint();
   }
@@ -212,7 +219,7 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
   
   public void unprogress()
   {
-    if (Preferences.getBoolean("editor.beep.compile")) {
+    if (PreferencesData.getBoolean("editor.beep.compile")) {
       Toolkit.getDefaultToolkit().beep();
     }
     if (progressBar == null) return;
@@ -247,7 +254,10 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
 
   public void paintComponent(Graphics screen) {
     //if (screen == null) return;
-    if (okButton == null) setup();
+    if (!initialized) {
+      setup();
+      initialized = true;
+    }
 
     //System.out.println("status.paintComponent");
 
@@ -325,7 +335,7 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
 
       // !@#(* aqua ui #($*(( that turtle-neck wearing #(** (#$@)(
       // os9 seems to work if bg of component is set, but x still a bastard
-      if (Base.isMacOS()) {
+      if (OSUtils.isMacOS()) {
         //yesButton.setBackground(bgcolor[EDIT]);
         //noButton.setBackground(bgcolor[EDIT]);
         cancelButton.setBackground(bgcolor[EDIT]);
@@ -438,7 +448,7 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
 
       progressBar = new JProgressBar(JScrollBar.HORIZONTAL);
       progressBar.setIndeterminate(false);
-      if (Base.isMacOS()) {
+      if (OSUtils.isMacOS()) {
         //progressBar.setBackground(bgcolor[PROGRESS]);
         //progressBar.putClientProperty("JProgressBar.style", "circular");
       }
@@ -448,25 +458,21 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
       add(progressBar);
       progressBar.setVisible(false);
       
-      copyErrorButton = new JButton(
-         "<html>" + _("Copy error") + "<br>" + _("to clipboard") + "</html>");
-      Font font = copyErrorButton.getFont();
-      font = new Font(font.getName(), font.getStyle(), (int) (font.getSize()*0.7));
-      copyErrorButton.setFont(font);
-      copyErrorButton.setHorizontalAlignment(JLabel.CENTER);
+      copyErrorButton = new JButton(_("Copy error messages"));
       add(copyErrorButton);
       copyErrorButton.setVisible(false);
       copyErrorButton.addActionListener(new ActionListener() {
         public void actionPerformed(ActionEvent e) {
-          String message="";
-          if ((Preferences.getBoolean("build.verbose")) == false) {
-            message = "  " + _("This report would have more information with") + "\n";
+          String message = "";
+          message += _("Arduino: ") + BaseNoGui.VERSION_NAME_LONG + " (" + System.getProperty("os.name") + "), ";
+          message += _("Board: ") + "\"" + BaseNoGui.getBoardPreferences().get("name") + "\"\n\n";
+          message += editor.console.consoleTextPane.getText().trim();
+          if ((PreferencesData.getBoolean("build.verbose")) == false) {
+            message += "\n\n";
+            message += "  " + _("This report would have more information with") + "\n";
             message += "  \"" + _("Show verbose output during compilation") + "\"\n";
             message += "  " + _("enabled in File > Preferences.") + "\n";
           }
-          message += _("Arduino: ") + Base.VERSION_NAME + " (" + System.getProperty("os.name") + "), ";
-          message += _("Board: ") + "\"" + Base.getBoardPreferences().get("name") + "\"\n";
-          message += editor.console.consoleTextPane.getText().trim();
           Clipboard clipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
           StringSelection data = new StringSelection(message);
           clipboard.setContents(data, null);
@@ -540,4 +546,8 @@ public class EditorStatus extends JPanel /*implements ActionListener*/ {
       }
     }
   }
+  
+  public boolean isInitialized() {
+    return initialized;
+  }
 }
