@@ -23,14 +23,22 @@
 
 package processing.app.tools;
 
-import processing.app.*;
-import static processing.app.I18n._;
+import org.apache.commons.compress.utils.IOUtils;
+import processing.app.Base;
+import processing.app.Editor;
+import processing.app.Sketch;
 
-import java.awt.FileDialog;
-import java.io.*;
-import java.text.*;
-import java.util.*;
-import java.util.zip.*;
+import java.awt.*;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.text.NumberFormat;
+import java.text.SimpleDateFormat;
+import java.util.Date;
+import java.util.zip.ZipEntry;
+import java.util.zip.ZipOutputStream;
+
+import static processing.app.I18n._;
 
 
 public class Archiver implements Tool {
@@ -105,8 +113,7 @@ public class Archiver implements Tool {
     } while (newbie.exists());
 
     // open up a prompt for where to save this fella
-    FileDialog fd =
-      new FileDialog(editor, _("Archive sketch as:"), FileDialog.SAVE);
+    FileDialog fd = new FileDialog(editor, _("Archive sketch as:"), FileDialog.SAVE);
     fd.setDirectory(parent.getAbsolutePath());
     fd.setFile(newbie.getName());
     fd.setVisible(true);
@@ -118,22 +125,21 @@ public class Archiver implements Tool {
     if (filename != null) {
       newbie = new File(directory, filename);
 
+      ZipOutputStream zos = null;
       try {
         //System.out.println(newbie);
-        FileOutputStream zipOutputFile = new FileOutputStream(newbie);
-        ZipOutputStream zos = new ZipOutputStream(zipOutputFile);
+        zos = new ZipOutputStream(new FileOutputStream(newbie));
 
         // recursively fill the zip file
         buildZip(location, name, zos);
 
         // close up the jar file
         zos.flush();
-        zos.close();
-
         editor.statusNotice("Created archive " + newbie.getName() + ".");
-
       } catch (IOException e) {
         e.printStackTrace();
+      } finally {
+        IOUtils.closeQuietly(zos);
       }
     } else {
       editor.statusNotice(_("Archive sketch canceled."));
@@ -144,6 +150,9 @@ public class Archiver implements Tool {
   public void buildZip(File dir, String sofar,
                        ZipOutputStream zos) throws IOException {
     String files[] = dir.list();
+    if (files == null) {
+      throw new IOException("Unable to list files from " + dir);
+    }
     for (int i = 0; i < files.length; i++) {
       if (files[i].equals(".") ||
           files[i].equals("..")) continue;
